summaryrefslogtreecommitdiffstats
path: root/src/fetch/configwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/fetch/configwidget.h')
-rw-r--r--src/fetch/configwidget.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/fetch/configwidget.h b/src/fetch/configwidget.h
index 55eafb0..7230cae 100644
--- a/src/fetch/configwidget.h
+++ b/src/fetch/configwidget.h
@@ -20,7 +20,7 @@
#include <tqdict.h>
#include <tqcheckbox.h>
-class KConfigGroup;
+class TDEConfigGroup;
class TQStringList;
namespace Tellico {
@@ -43,9 +43,9 @@ public:
* Saves any configuration options. The config group must be
* set before calling this function.
*
* @param config_ The KConfig pointer
*/
- virtual void saveConfig(KConfigGroup& config) = 0;
+ virtual void saveConfig(TDEConfigGroup& config) = 0;
/**
* Called when a fetcher data source is removed. Useful for any cleanup work necessary.
* The ExecExternalFetcher might need to remove the script, for example.
@@ -64,7 +64,7 @@ public slots:
protected:
TQWidget* optionsWidget() { return m_optionsWidget; }
void addFieldsWidget(const StringMap& customFields, const TQStringList& fieldsToAdd);
- void saveFieldsConfig(KConfigGroup& config) const;
+ void saveFieldsConfig(TDEConfigGroup& config) const;
private:
bool m_modified;
@@ -43,9 +43,9 @@ public:
* set before calling this function.
*
- * @param config_ The KConfig pointer
+ * @param config_ The TDEConfig pointer
*/